@@ -85,6 +85,18 @@ class SkeletonVisualizer:
         self.__display_checkboxes(include_names, include_coordinates)
         self.__display_color_changer()
 
+    def visualize_with_ground_truths(self, pred_skeletons: np.ndarray, gt_skeletons: np.ndarray,
+                                     pred_colors: List[Color] = None, gt_colors: List[Color] = None,
+                                     include_names: bool = False, include_coordinates: bool = False,
+                                     automatic_camera_orientation: bool = False) -> None:
+        assert pred_skeletons.shape == gt_skeletons.shape, \
+            'The predicate and ground truth skeleton arrays must have the same shape.'
+        pred_colors = self.__init_colors(pred_skeletons.shape[0], pred_colors)
+        gt_colors = self.__init_colors(gt_skeletons.shape[0], gt_colors)
+        skeletons: np.ndarray = np.concatenate((pred_skeletons, gt_skeletons), axis=0)
+        colors: List[Color] = pred_colors + gt_colors
+        self.visualize(skeletons, colors, include_names, include_coordinates, automatic_camera_orientation)
+
     def visualize_video_from_file(self, file_name: str, colors: List[Color] = None, fps: int = 15,
                                   include_names: bool = False, include_coordinates: bool = False,
                                   automatic_camera_orientation: bool = False) -> None:
@@ -136,8 +148,8 @@ class SkeletonVisualizer:
 
     def __init_skeleton_plot(self, skeletons: np.ndarray, automatic_camera_orientation: bool = False) -> None:
         self.plot = k3d.plot(antialias=1, camera_auto_fit=False)
+        centroid: np.ndarray = np.average(np.average(skeletons, axis=0), axis=0)
         if automatic_camera_orientation:
-            centroid: np.ndarray = np.average(np.average(skeletons, axis=0), axis=0)
             camera_up_vector: np.ndarray = np.zeros(shape=(3,))
             for line_indices in self.joint_set.vertically_aligned_line_indices:
                 camera_up_vector += np.sum(
@@ -149,20 +161,24 @@ class SkeletonVisualizer:
                 centroid[0], centroid[1], centroid[2],
                 camera_up_vector[0], camera_up_vector[1], camera_up_vector[2]]
         else:
-            self.plot.camera = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0, -1.0, 0.0]
+            self.plot.camera = [0.0, 0.0, 0.0, 0.0, 0.0, centroid[2], 0.0, -1.0, 0.0]
 
     def __calculate_skeleton_part_size(self, skeletons: np.ndarray) -> float:
         max_values = [abs(skeleton).max() for skeleton in skeletons]
         return (min(max_values) / 100.0) * self.size_scalar
 
     def __get_skeletons(self, positions: List[Positions], colors: List[Color],
-                        skeleton_part_size: float) -> List[Skeleton]:
-        return list(map(lambda position_color_tuple: Skeleton(
-            joint_positions=position_color_tuple[0],
+                        skeleton_part_size: float, is_gt_list: List[bool] = None) -> List[Skeleton]:
+        length: int = len(positions)
+        if is_gt_list is None:
+            is_gt_list = [False] * length
+        return list(map(lambda parameter_tuple: Skeleton(
+            joint_positions=parameter_tuple[0],
             joint_set=self.joint_set,
             part_size=skeleton_part_size,
-            color=position_color_tuple[1]
-        ), zip(positions, colors)))
+            color=parameter_tuple[1],
+            is_ground_truth=parameter_tuple[2]
+        ), zip(positions, colors, is_gt_list)))
 
     def __add_skeletons_to_plot(self, skeletons: List[DrawableSkeleton]) -> None:
         for drawable_skeleton in skeletons:
